package org.ow2.util.ee.metadata.car.impl.configurator;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.ee.deploy.api.deployable.CARDeployable;
import org.ow2.util.ee.metadata.car.impl.CarDeployableMetadata;
import org.ow2.util.ee.metadata.car.impl.specific.ISpecificCarDeployableMetadataConfigurator;
import org.ow2.util.scan.api.configurator.IArchiveConfigurator;
import org.ow2.util.scan.api.configurator.IClassConfigurator;
import org.ow2.util.scan.api.metadata.structures.JClass;

/**
 * EjbJarArchiveMetadataConfigurator.
 * @author Gael Lalire
 */
public class CarDeployableMetadataConfigurator implements IArchiveConfigurator {

    /**
     * The list of specific configurator.
     */
    private List<ISpecificCarDeployableMetadataConfigurator> specificCarDeployableFactoryList;

    /**
     * archive metadata.
     */
    private CarDeployableMetadata carDeployableMetadata;

    /**
     * annotationParsingDesactived.
     */
    private boolean annotationParsingDesactived;

    /**
     * Constructor.
     * @param carDeployable the client archive
     */
    public CarDeployableMetadataConfigurator(final CARDeployable carDeployable) {
        this.carDeployableMetadata = new CarDeployableMetadata(carDeployable);
        this.annotationParsingDesactived = false;
        specificCarDeployableFactoryList = new ArrayList<ISpecificCarDeployableMetadataConfigurator>();
    }

    /**
     * @param jClass signature
     * @return class configurator
     */
    public IClassConfigurator createClassConfigurator(final JClass jClass) {
        return new CarClassMetadataConfigurator(jClass, this.carDeployableMetadata, annotationParsingDesactived,
                specificCarDeployableFactoryList);
    }

    /**
     * @return the archive metadata
     */
    public CarDeployableMetadata getCarDeployableMetadata() {
        return this.carDeployableMetadata;
    }

    /**
     * Set annotationParsingDesactived.
     * @param annotationParsingDesactived true if you want to desactive annotation parsing
     */
    public void setAnnotationParsingDesactived(final boolean annotationParsingDesactived) {
        this.annotationParsingDesactived = annotationParsingDesactived;
    }

    /**
     * @param specificCarDeployableFactory add a specific configurator to the list
     */
    public void addSpecificMetadataConfigurator(final ISpecificCarDeployableMetadataConfigurator specificCarDeployableFactory) {
        specificCarDeployableFactoryList.add(specificCarDeployableFactory);
    }

    /**
     * @return the list of specific configurator.
     */
    public List<ISpecificCarDeployableMetadataConfigurator> getSpecificEjbJarDeployableFactoryList() {
        return specificCarDeployableFactoryList;
    }


}
